@@ -113,7 +113,7 @@ const char *prgname;
 
 void xalloc_die(void)
 {
-    fprintf(stderr, _("%s: FATAL: %s"), prgname, strerror(ENOMEM));
+    fprintf(stderr, _("%s: FATAL: %s\n"), prgname, strerror(ENOMEM));
     exit(EX_OSERR);
 }
 
@@ -747,18 +747,14 @@ int mpop_serverinfo(account_t *acc, int debug, char **errmsg, char **errstr)
     {
         printf("PLAIN ");
     }
-    if (session->cap.flags & POP3_CAP_AUTH_CRAM_MD5)
-    {
-        printf("CRAM-MD5 ");
-    }
-    if (session->cap.flags & POP3_CAP_AUTH_DIGEST_MD5)
-    {
-        printf("DIGEST-MD5 ");
-    }
     if (session->cap.flags & POP3_CAP_AUTH_SCRAM_SHA_1)
     {
         printf("SCRAM-SHA-1 ");
     }
+    if (session->cap.flags & POP3_CAP_AUTH_CRAM_MD5)
+    {
+        printf("CRAM-MD5 ");
+    }
     if (session->cap.flags & POP3_CAP_AUTH_GSSAPI)
     {
         printf("GSSAPI ");
@@ -767,6 +763,10 @@ int mpop_serverinfo(account_t *acc, int debug, char **errmsg, char **errstr)
     {
         printf("EXTERNAL ");
     }
+    if (session->cap.flags & POP3_CAP_AUTH_DIGEST_MD5)
+    {
+        printf("DIGEST-MD5 ");
+    }
     if (session->cap.flags & POP3_CAP_AUTH_LOGIN)
     {
         printf("LOGIN ");
@@ -2289,18 +2289,14 @@ int main(int argc, char *argv[])
         {
             printf("plain ");
         }
-        if (pop3_client_supports_authmech("CRAM-MD5"))
-        {
-            printf("cram-md5 ");
-        }
-        if (pop3_client_supports_authmech("DIGEST-MD5"))
-        {
-            printf("digest-md5 ");
-        }
         if (pop3_client_supports_authmech("SCRAM-SHA-1"))
         {
             printf("scram-sha-1 ");
         }
+        if (pop3_client_supports_authmech("CRAM-MD5"))
+        {
+            printf("cram-md5 ");
+        }
         if (pop3_client_supports_authmech("GSSAPI"))
         {
             printf("gssapi ");
@@ -2309,6 +2305,10 @@ int main(int argc, char *argv[])
         {
             printf("external ");
         }
+        if (pop3_client_supports_authmech("DIGEST-MD5"))
+        {
+            printf("digest-md5 ");
+        }
         if (pop3_client_supports_authmech("LOGIN"))
         {
             printf("login ");
@@ -2347,7 +2347,7 @@ int main(int argc, char *argv[])
 # endif
 #endif
         printf("\n\n");
-        printf(_("Copyright (C) 2010 Martin Lambers and others.\n"
+        printf(_("Copyright (C) 2011 Martin Lambers and others.\n"
                     "This is free software.  You may redistribute copies of "
                         "it under the terms of\n"
                     "the GNU General Public License "
@@ -2438,7 +2438,8 @@ int main(int argc, char *argv[])
                 prgname, prgname, prgname, prgname, PACKAGE_BUGREPORT);
     }
 
-    if (!retrmail && !serverinfo && !print_conf)
+    if (print_help || print_version
+            || (!retrmail && !serverinfo && !print_conf))
     {
         error_code = EX_OK;
         goto exit;
